package com.ruoyi.bst.device.service;

import java.util.List;

import com.ruoyi.bst.device.domain.Device;
import com.ruoyi.bst.device.domain.DeviceQuery;
import com.ruoyi.bst.device.domain.DeviceVO;

/**
 * 设备Service接口
 *
 * @author ruoyi
 * @date 2025-04-17
 */
public interface DeviceService
{
    /**
     * 查询设备
     *
     * @param id 设备主键
     * @return 设备
     */
    public DeviceVO selectDeviceById(Long id);

    /**
     * 查询设备列表
     *
     * @param device 设备
     * @return 设备集合
     */
    public List<DeviceVO> selectDeviceList(DeviceQuery device);

    /**
     * 新增设备
     *
     * @param device 设备
     * @return 结果
     */
    public int insertDevice(Device device);

    /**
     * 修改设备
     *
     * @param device 设备
     * @return 结果
     */
    public int updateDevice(Device device);

    /**
     * 批量删除设备
     *
     * @param ids 需要删除的设备主键集合
     * @return 结果
     */
    public int deleteDeviceByIds(Long[] ids);

    /**
     * 删除设备信息
     *
     * @param id 设备主键
     * @return 结果
     */
    public int deleteDeviceById(Long id);

    /**
     * 根据MAC查询设备
     * @param mac 设备MAC
     * @return 设备
     */
    public DeviceVO selectDeviceByMac(String mac);

    /**
     * 根据数据点查询相似的设备MAC
     * @param macPrefix MAC前缀
     * @return 设备MAC
     */
    public String selectOneMacByPrefix(String macPrefix);
}
