package com.ruoyi.bst.gatewayDevice.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.gatewayDevice.domain.GatewayDevice;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceQuery;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceVO;
import com.ruoyi.bst.gatewayDevice.domain.vo.GatewayStatusCountGroupByDeviceVO;

/**
 * 网关设备Mapper接口
 *
 * @author ruoyi
 * @date 2025-04-17
 */
public interface GatewayDeviceMapper
{
    /**
     * 查询网关设备
     *
     * @param id 网关设备主键
     * @return 网关设备
     */
    GatewayDeviceVO selectGatewayDeviceById(Long id);

    /**
     * 查询网关设备列表
     *
     * @param query 网关设备
     * @return 网关设备集合
     */
    List<GatewayDeviceVO> selectGatewayDeviceList(@Param("query")GatewayDeviceQuery query);

    /**
     * 新增网关设备
     *
     * @param gatewayDevice 网关设备
     * @return 结果
     */
    int insertGatewayDevice(GatewayDevice gatewayDevice);

    /**
     * 批量新增网关设备
     */
    int batchInsert(@Param("list") List<? extends GatewayDevice> list);

    /**
     * 批量修改网关设备
     */
    int batchUpdate(@Param("list") List<? extends GatewayDevice> list);

    /**
     * 修改网关设备
     *
     * @param gatewayDevice 网关设备
     * @return 结果
     */
    public int updateGatewayDevice(@Param("data") GatewayDevice gatewayDevice);

    /**
     * 删除网关设备
     *
     * @param id 网关设备主键
     * @return 结果
     */
    int deleteGatewayDeviceById(Long id);

    /**
     * 批量删除网关设备
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGatewayDeviceByIds(Long[] ids);

    /**
     * 根据网关mac和设备mac更新网关设备
     * 
     * @param data 网关设备
     * @return 结果
     */
    int updateByGatewayAndDeviceMac(@Param("data") GatewayDevice data);

    /**
     * 查询网关状态统计，并按设备分组
     * 
     * @param query 网关设备查询条件
     * @return 网关状态统计结果
     */
    List<GatewayStatusCountGroupByDeviceVO> selectGatewayStatusCountGroupByDevice(@Param("query") GatewayDeviceQuery query);
}
